# Welcome to pro-football-reference-web-scraper's documentation!

[![](https://img.shields.io/github/license/mjk2244/pro-football-reference-web-scraper)](https://opensource.org/licenses/Apache-2.0) ![](https://img.shields.io/github/issues/mjk2244/pro-football-reference-web-scraper) [![](https://codecov.io/gh/mjk2244/pro-football-reference-web-scraper/branch/main/graph/badge.svg?token=OTGOR2M0CY)](https://codecov.io/gh/mjk2244/pro-football-reference-web-scraper) [![](https://img.shields.io/github/actions/workflow/status/mjk2244/pro-football-reference-web-scraper/build.yml)](https://github.com/mjk2244/pro-football-reference-web-scraper/) [![](https://img.shields.io/pypi/v/pro-football-reference-web-scraper)](https://pypi.org/project/pro-football-reference-web-scraper/)
## Overview
pro-football-reference-web-scraper is a Python library that helps developers take advantage of the plethora of free data provided by [Pro Football Reference](https://www.pro-football-reference.com/). It is intended primarily to help fantasy sports players and sports bettors gain an edge in their NFL sports gaming endeavors. However, it can be used for any project that requires team- and player-specific data.

```eval_rst

.. toctree::
   :maxdepth: 10
   :caption: Contents:

   README.md
   get_player_game_log.md
   get_team_game_log.md
   player_splits.md
   team_splits.md
   CONTRIBUTING.md
   source/modules

```
